/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics.matcher;

import com.topcoder.file.statistics.FileMatcher;
import com.topcoder.file.statistics.FileMatchingException;
import java.io.File;


/**
 * <p>
 * FileNameMatcher is a template class that handles filename oriented matching logic.
 * </p>
 *
 * <p>
 * Thread Safety: This class is stateless and thread-safe.
 * </p>
 *
 * @author WishingBone, TCSDEVELOPER
 * @version 1.0
 */
public abstract class FileNameMatcher implements FileMatcher {
    /**
     * <p>
     * Default protected constructor.
     * </p>
     */
    protected FileNameMatcher() {
        // empty
    }

    /**
     * <p>
     * Retruns whether the given File mathcs.
     * </p>
     *
     * @param file the file to match
     *
     * @return whether the file matches
     *
     * @throws NullPointerException if file is null
     * @throws FileMatchingException if some unexpected error occurs
     */
    public boolean match(File file) throws FileMatchingException {
        MatcherHelper.checkNull(file, "file");

        // delegate to match(String) method
        return match(file.getName());
    }

    /**
     * <p>
     * Template method to match a filename.
     * </p>
     *
     * @param filename the filename to match
     *
     * @return whether the filename matches
     *
     * @throws FileMatchingException if error occurs
     */
    protected abstract boolean match(String filename) throws FileMatchingException;
}
