/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics;

import junit.framework.TestCase;
import java.util.HashSet;
import java.util.List;


/**
 * <p>
 * Unit test cases for StatsResult.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class StatsResultTests extends TestCase {
    /**
     * A Metric instance to test.
     */
    private Metric metric1 = null;

    /**
     * A Metric instance to test.
     */
    private Metric metric2 = null;

    /**
     * A Metric instance to test.
     */
    private Metric metric3 = null;

    /**
     * A StatsResult instance to test.
     */
    private StatsResult result = null;

    /**
     * Creates an empty StatsResult instance.
     */
    protected void setUp() {
        result = new StatsResult();
        metric1 = new Metric("foo", "foo", "foo");
        metric2 = new Metric("bar", "bar", "bar");
        metric3 = new Metric("foobar", "bar", "bar");
    }

    /**
     * <p>
     * Verifies the constructor.
     * </p>
     */
    public void testStatsResult1() {
        assertNotNull("Unable to instantiate StatsResult.", new StatsResult());
    }

    /**
     * <p>
     * Verifies the constructor.
     * </p>
     */
    public void testStatsResult2() {
        result.setStat(metric1, 1);

        assertTrue("Unable to instantiate StatsResult.",
            new StatsResult(result).getStat(metric1) == 1);
    }

    /**
     * <p>
     * Tests the setStat method.
     * </p>
     */
    public void testSetStat1() {
        result.setStat(metric1, 1);
        assertTrue("thre result should be 1", result.getStat(metric1) == 1);
        result.setStat(metric1, 2);
        assertTrue("thre result should be 2", result.getStat(metric1) == 2);
    }

    /**
     * <p>
     * Tests the setStat method with null argument. NullPointerException should be thrown.
     * </p>
     */
    public void testSetStat2() {
        try {
            result.setStat(null, 100);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // seccuss
        }
    }

    /**
     * <p>
     * Tests the getStat method.
     * </p>
     */
    public void testGetStat1() {
        result.setStat(metric1, 1);
        assertTrue("thre result should be 1", result.getStat(metric1) == 1);
    }

    /**
     * <p>
     * Tests the getStat method with null argument. NullPointerException should be thrown.
     * </p>
     */
    public void testGetStat2() {
        try {
            result.getStat(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // seccuss
        }
    }

    /**
     * <p>
     * Tests the getStat method with invalid argument. IllegalArgumentException should be thrown.
     * </p>
     */
    public void testGetStat3() {
        try {
            result.getStat(metric2);
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // seccuss
        }
    }

    /**
     * <p>
     * Tests the getMetrics method.
     * </p>
     */
    public void testGetMetrics1() {
        assertEquals("size should be 0", 0, result.getMetrics().size());
    }

    /**
     * <p>
     * Tests the getAllKeys method.
     * </p>
     */
    public void testGetAllKeys2() {
        result.setStat(metric1, 1);
        result.setStat(metric2, 1);
        result.setStat(metric1, 2);

        List keys = result.getMetrics();

        assertEquals("size should be 2", 2, keys.size());

        assertTrue("the list should contains metric1", new HashSet(keys).contains(metric1));
        assertTrue("the list should contains metric2", new HashSet(keys).contains(metric1));
    }

    /**
     * <p>
     * Tests the aggregate method.
     * </p>
     */
    public void testAggregate1() {
        StatsResult result1 = new StatsResult();
        result1.setStat(metric1, 10);
        result1.setStat(metric2, 20);

        StatsResult result2 = new StatsResult();
        result2.setStat(metric2, 30);
        result2.setStat(metric3, 0);

        result1.aggregate(result2);

        assertEquals("the result should be 10", 10, result1.getStat(metric1));
        assertEquals("the result should be 50", 50, result1.getStat(metric2));
        assertEquals("the result should be 0", 0, result1.getStat(metric3));
    }

    /**
     * <p>
     * Tests the aggregate method.
     * </p>
     */
    public void testAggregate2() {
        StatsResult result2 = new StatsResult();
        result2.setStat(metric2, 30);
        result2.setStat(metric3, 0);

        result.aggregate(result2);

        assertEquals("the result should be 30", 30, result.getStat(metric2));
        assertEquals("the result should be 0", 0, result.getStat(metric3));
    }

    /**
     * <p>
     * Tests the aggregate method.
     * </p>
     */
    public void testAggregate3() {
        result.setStat(metric2, 30);
        result.setStat(metric3, 0);

        result.aggregate(new StatsResult());

        assertEquals("the result should be 30", 30, result.getStat(metric2));
        assertEquals("the result should be 0", 0, result.getStat(metric3));
    }

    /**
     * <p>
     * Tests the aggregate method with null argument. NullPointerException should be thrown.
     * </p>
     */
    public void testAggregate4() {
        try {
            result.aggregate(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // seccuss
        }
    }
}
