/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved
 */
package com.topcoder.file.statistics;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import com.topcoder.file.statistics.matcher.AnyFileMatcherTests;
import com.topcoder.file.statistics.matcher.BinaryFileMatcherTests;
import com.topcoder.file.statistics.matcher.ExtensionMatcherTests;
import com.topcoder.file.statistics.matcher.RegexMatcherTests;
import com.topcoder.file.statistics.matcher.TextFileMatcherTests;
import com.topcoder.file.statistics.matcher.TypeMimeMatcherTests;
import com.topcoder.file.statistics.matcher.TypeNameMatcherTests;
import com.topcoder.file.statistics.processor.linecounter.CStyleLineCounterTests;
import com.topcoder.file.statistics.processor.linecounter.TextLineCounterTests;
import com.topcoder.file.statistics.reporting.BasicStatsReportingTests;
import com.topcoder.file.statistics.reporting.StatsCollectionTests;
import com.topcoder.file.statistics.reporting.XmlStatsReportingTests;


/**
 * <p>
 * This test case aggregates all Unit test cases.
 * </p>
 *
 * @author TopCoder
 * @version 1.0
 */
public class UnitTests extends TestCase {
    /**
     * Returns the test suite.
     *
     * @return the test suite
     */
    public static Test suite() {
        final TestSuite suite = new TestSuite();

        // matcher package
        suite.addTestSuite(AnyFileMatcherTests.class);
        suite.addTestSuite(ExtensionMatcherTests.class);
        suite.addTestSuite(RegexMatcherTests.class);
        suite.addTestSuite(TextFileMatcherTests.class);
        suite.addTestSuite(BinaryFileMatcherTests.class);
        suite.addTestSuite(TypeNameMatcherTests.class);
        suite.addTestSuite(TypeMimeMatcherTests.class);

        // processor package
        suite.addTestSuite(TextLineCounterTests.class);
        suite.addTestSuite(CStyleLineCounterTests.class);

        // report package
        suite.addTestSuite(StatsCollectionTests.class);
        suite.addTestSuite(BasicStatsReportingTests.class);
        suite.addTestSuite(XmlStatsReportingTests.class);

        // main package
        suite.addTestSuite(MetricTests.class);
        suite.addTestSuite(StatsResultTests.class);
        suite.addTestSuite(FileStatisticsTests.class);
        suite.addTestSuite(ExtendedFileStatisticsTests.class);
        suite.addTestSuite(MainTests.class);
        suite.addTestSuite(Demo.class);

        // exceptions
        suite.addTestSuite(ConfigurationExceptionTests.class);
        suite.addTestSuite(StatsReportingExceptionTests.class);
        suite.addTestSuite(FileProcessingExceptionTests.class);
        suite.addTestSuite(FileMatchingExceptionTests.class);
        suite.addTestSuite(FileStatisticsExceptionTests.class);

        return suite;
    }
}
