/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved
 */
 package com.topcoder.file.statistics.failuretests;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import com.topcoder.file.statistics.failuretests.matcher.*;
import com.topcoder.file.statistics.failuretests.processor.linecounter.CStyleLineCounterTests;
import com.topcoder.file.statistics.failuretests.processor.linecounter.TextLineCounterTests;
import com.topcoder.file.statistics.failuretests.reporting.BasicStatsReportingTests;
import com.topcoder.file.statistics.failuretests.reporting.StatsCollectionTests;
import com.topcoder.file.statistics.failuretests.reporting.XmlStatsReportingTests;

/**
 * <p>This test case aggregates all Failure test cases.</p>
 *
 * @author TopCoder
 * @version 1.0
 */
public class FailureTests extends TestCase {

	/**
	 * Returns the failure tests suite.
	 * 
	 * @return a Test containing the failure tests suite for this component.
	 */
    public static Test suite() {
        final TestSuite suite = new TestSuite();
        
        // framework classes
        suite.addTest(new TestSuite(FileStatisticsTests.class));
        suite.addTest(new TestSuite(ExtendedFileStatisticsTests.class));
        suite.addTest(new TestSuite(MetricTests.class));
        suite.addTest(new TestSuite(StatsResultTests.class));
        
        // exceptions
        suite.addTest(new TestSuite(ConfigurationExceptionTests.class));
        suite.addTest(new TestSuite(FileMatchingExceptionTests.class));
        suite.addTest(new TestSuite(FileProcessingExceptionTests.class));
        suite.addTest(new TestSuite(FileStatisticsExceptionTests.class));
        suite.addTest(new TestSuite(StatsReportingExceptionTests.class));
        
        // matcher
        suite.addTest(new TestSuite(AnyFileMatcherTests.class));
        suite.addTest(new TestSuite(BinaryFileMatcherTests.class));
        suite.addTest(new TestSuite(ExtensionMatcherTests.class));
        suite.addTest(new TestSuite(FileCategoryMatcherTests.class));
        suite.addTest(new TestSuite(MimeMatcherTests.class));
        suite.addTest(new TestSuite(RegexMatcherTests.class));
        suite.addTest(new TestSuite(TextFileMatcherTests.class));
        suite.addTest(new TestSuite(TypeNameMatcherTests.class));
        
        // processor
        suite.addTest(new TestSuite(CStyleLineCounterTests.class));
        suite.addTest(new TestSuite(TextLineCounterTests.class));
        
        // reporting
        suite.addTest(new TestSuite(BasicStatsReportingTests.class));
        suite.addTest(new TestSuite(StatsCollectionTests.class));
        suite.addTest(new TestSuite(XmlStatsReportingTests.class));
        
        return suite;
    }

}
