/*
 * $(#)FileStatisticsTests.java		Sep 6, 2005
 * 
 * Copyright (c) 2005, TopCoder Inc. All rights reserved.
 */

package com.topcoder.file.statistics.failuretests;

import junit.framework.TestCase;

import com.topcoder.file.statistics.ConfigurationException;
import com.topcoder.file.statistics.FileStatistics;
import com.topcoder.util.config.ConfigManager;

/**
 * This test case contains the failure tests for the <code>FileStatistics</code>
 * class.
 *
 * @author MPhk
 * @version 1.0
 */
public class FileStatisticsTests extends TestCase {

    /**
     * The namespace for this test.
     */
    private static final String NAMESPACE = "com.topcoder.file.statistics.failuretests";

    /**
     * An FileStatistics instance to test.
     */
    private FileStatistics fileStatistics = null;

    /**
     * Creates an FileStatistics instance.
     *
     * @throws Exception in case anything goes wrong
     */
    protected void setUp() throws Exception {
        fileStatistics = new FileStatistics();
    }

    /**
     * Checks whether the constructor - FileStatistics(String) properly throws
     * NullPointerException for null argument.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testFileStatistics1() throws Exception {
        try {
            new FileStatistics(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor - FileStatistics(String) properly throws
     * IllegalArgumentException for empty String argument.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testFileStatistics2() throws Exception {
        try {
            new FileStatistics(" ");
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor - FileStatistics(String) properly throws
     * ConfigurationException for invalid configuration.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testFileStatistics3() throws Exception {
        final String CONFIG_FILE = "failuretests/invalid1.xml";
        // clear the namespace first
        ConfigManager configManager = ConfigManager.getInstance();
        if (configManager.existsNamespace(NAMESPACE)) {
            configManager.removeNamespace(NAMESPACE);
        }
        // load the configuration
        ConfigManager.getInstance().add(CONFIG_FILE);

        try {
            new FileStatistics(NAMESPACE);
            fail("ConfigurationException should be thrown.");
        } catch (ConfigurationException e) {
            // success
        } finally {
            if (configManager.existsNamespace(NAMESPACE)) {
                configManager.removeNamespace(NAMESPACE);
            }
        }
    }

    /**
     * Checks whether the constructor - FileStatistics(String) properly throws
     * ConfigurationException for invalid configuration.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testFileStatistics4() throws Exception {
        final String CONFIG_FILE = "failuretests/invalid2.xml";
        // clear the namespace first
        ConfigManager configManager = ConfigManager.getInstance();
        if (configManager.existsNamespace(NAMESPACE)) {
            configManager.removeNamespace(NAMESPACE);
        }
        // load the configuration
        ConfigManager.getInstance().add(CONFIG_FILE);

        try {
            new FileStatistics(NAMESPACE);
            fail("ConfigurationException should be thrown.");
        } catch (ConfigurationException e) {
            // success
        } finally {
            if (configManager.existsNamespace(NAMESPACE)) {
                configManager.removeNamespace(NAMESPACE);
            }
        }
    }

    /**
     * Checks whether the method addFileProcessor(String) properly throws
     * NullPointerException for null argument.
     */
    public void testAddFileProcessor() {
        try {
            this.fileStatistics.addFileProcessor(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the method removeFileProcessor(String) properly throws
     * NullPointerException for null argument.
     */
    public void testRemoveFileProcessor1() {
        try {
            this.fileStatistics.removeFileProcessor(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the method removeFileProcessor(String) properly throws
     * IllegalArgumentException for empty String argument.
     */
    public void testRemoveFileProcessor2() {
        try {
            this.fileStatistics.removeFileProcessor(" ");
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }
    
    /**
     * Checks whether the method setReporting(StatsReporting) properly throws
     * NullPointerException for null argument.
     */
    public void testSetReporting() {
        try {
            this.fileStatistics.setReporting(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the method processFile(File) properly throws
     * NullPointerException for null argument.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testProccessFile() throws Exception {
        try {
            this.fileStatistics.processFile(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

}
