/*
 * $(#)StatsCollectionTests.java		Sep 6, 2005
 * 
 * Copyright (c) 2005, TopCoder Inc. All rights reserved.
 */

package com.topcoder.file.statistics.failuretests.reporting;

import junit.framework.TestCase;

import com.topcoder.file.statistics.StatsResult;
import com.topcoder.file.statistics.reporting.StatsCollection;

/**
 * This test case contains the failure tests for the <code>StatsCollection</code>
 * class.
 *
 * @author MPhk
 * @version 1.0
 */
public class StatsCollectionTests extends TestCase {

    /**
     * A StatsCollection instance to test.
     */
    private StatsCollection collection = null;

    /**
     * Sets up this test.
     */
    protected void setUp() {
        collection = new StatsCollection();
    }

    /**
     * Checks whether the add method properly throws NullPointerException for 
     * null argument.
     */
    public void testAdd1() {
        try {
            collection.add(null, new StatsResult());
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the add method properly throws NullPointerException for 
     * null argument.
     */
    public void testAdd2() {
        try {
            collection.add("key", null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }
    
    /**
     * Checks whether the add method properly throws IllegalArgumentException for 
     * empty String argument. 
     */
    public void testAdd3() {
        try {
            collection.add(" ", new StatsResult());
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

    /**
     * Checks whether the add method properly throws NullPointerException for 
     * null argument. 
     */
    public void testGet1() {
        try {
            collection.get(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }
    
    /**
     * Checks whether the get method properly throws IllegalArgumentException for 
     * empty String argument. 
     */
    public void testGet2() {
        try {
            collection.get(" ");
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

}
