/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics.matcher;

import com.topcoder.util.config.Property;
import junit.framework.TestCase;
import java.io.File;
import java.io.IOException;

/**
 * <p>
 * Unit test cases for TextFileMatcher.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class TextFileMatcherTests extends TestCase {

    /**
     * The the base path of the test files.
     */
    private static final String BASE_PATH = "test_files/matcher/";

    /**
     * An TextFileMatcher instance to test.
     */
    private TextFileMatcher matcher = null;

    /**
     * Creates a TextFileMatcher instance for test.
     */
    protected void setUp() {
        matcher = new TextFileMatcher();
    }

    /**
     * <p>
     * Verifies the constructor - TextFileMatcher(String).
     * </p>
     */
    public void testTextFileMatcher1() {
        assertTrue("Unable to instantiate TextFileMatcher.",
            new TextFileMatcher() instanceof TextFileMatcher);
    }

    /**
     * <p>
     * Verifies the constructor - TextFileMatcher(Property).
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testTextFileMatcher3() throws Exception {
        assertTrue("Unable to instantiate TextFileMatcher.",
            new TextFileMatcher(new Property("foo")) instanceof TextFileMatcher);
    }

    /**
     * <p>
     * Verifies the constructor - TextFileMatcher(Property) with null argument.
     * NullPointerException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testTextFileMatcher4() throws Exception {
        try {
            new TextFileMatcher((Property) null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * <p>
     * Tests the match method with null argument. NullPointerException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch1() throws Exception {
        try {
            matcher.match((File) null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * <p>
     * Tests the match method with invalid File. IOException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch2() throws Exception {
        try {
            matcher.match(new File(BASE_PATH));
            fail("IOException should be thrown");
        } catch (IOException e) {
            // success
        }
    }

    /**
     * <p>
     * Tests the match method. Validates a text file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch3() throws Exception {
        assertTrue("The result should be true", matcher.match(new File(BASE_PATH, "test1.txt")));
    }

    /**
     * <p>
     * Tests the match method. Validates a text file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch4() throws Exception {
        assertTrue("The result should be true", matcher.match(new File(BASE_PATH, "test2.txt")));
    }

    /**
     * <p>
     * Tests the match method. Validates a binary file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch5() throws Exception {
        assertFalse("The result should be false", matcher.match(new File(BASE_PATH, "test1.bin")));
    }

    /**
     * <p>
     * Tests the match method. Validates a binary file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch6() throws Exception {
        assertFalse("The result should be false", matcher.match(new File(BASE_PATH, "test2.bin")));
    }

    /**
     * <p>
     * Tests the match method. Validates an empty file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch7() throws Exception {
        assertTrue("The result should be false", matcher.match(new File(BASE_PATH, "empty")));
    }



    /**
     * <p>
     * Tests the isBinary method with null argument. NullPointerException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary1() throws Exception {
        try {
            TextFileMatcher.isBinary((File) null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * <p>
     * Tests the isBinary method with invalid File. IOException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary2() throws Exception {
        try {
            TextFileMatcher.isBinary(new File(BASE_PATH));
            fail("IOException should be thrown");
        } catch (IOException e) {
            // success
        }
    }

    /**
     * <p>
     * Tests the isBinary method. Validates a text file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary3() throws Exception {
        assertFalse("The result should be false", TextFileMatcher.isBinary(new File(BASE_PATH, "test1.txt")));
    }

    /**
     * <p>
     * Tests the isBinary method. Validates a text file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary4() throws Exception {
        assertFalse("The result should be false", TextFileMatcher.isBinary(new File(BASE_PATH, "test2.txt")));
    }

    /**
     * <p>
     * Tests the isBinary method. Validates a binary file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary5() throws Exception {
        assertTrue("The result should be true", TextFileMatcher.isBinary(new File(BASE_PATH, "test1.bin")));
    }

    /**
     * <p>
     * Tests the isBinary method. Validates a binary file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary6() throws Exception {
        assertTrue("The result should be true", TextFileMatcher.isBinary(new File(BASE_PATH, "test2.bin")));
    }

    /**
     * <p>
     * Tests the isBinary method. Validates an empty file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary7() throws Exception {
        assertFalse("The result should be false", TextFileMatcher.isBinary(new File(BASE_PATH, "empty")));
    }
}
