package com.topcoder.file.statistics.stresstests;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import java.io.*;
import java.util.List;
import java.util.ArrayList;
import java.util.Date;

import com.topcoder.file.statistics.ExtendedFileStatistics;
import com.topcoder.file.statistics.FileMatcher;
import com.topcoder.file.statistics.FileProcessor;
import com.topcoder.file.statistics.StatsReporting;
import com.topcoder.file.statistics.reporting.BasicStatsReporting;
import com.topcoder.file.statistics.processor.linecounter.TextLineCounter;
import com.topcoder.file.statistics.matcher.*;

public class DirectoriesTests extends TestCase {
    public static Test suite() {
        return new TestSuite(DirectoriesTests.class);
    }

    private int levels = 4;

    private int childrenAtLevel = 4;

    private int filesInNode = 10;

    private String STANDARD_FILE_CONTENT = "....";

    ExtendedFileStatistics statistics;

    FileMatcher matcher1;

    FileProcessor processor1;

    StatsReporting reporting1;

    private List files = new ArrayList();
    private List folders = new ArrayList();

    public void setUp()
    {
        // create a file statistics instance
        statistics = new ExtendedFileStatistics();

        // create file matchers
        matcher1 = new AnyFileMatcher();

        // create file processors
        processor1 = new TextLineCounter("Text File", matcher1);

        // create stats reporting implementation
        reporting1 = new BasicStatsReporting();

        //assign the report object
        statistics.setReporting(reporting1);

        // manipulate file processors
        statistics.addFileProcessor(processor1);

        try
        {
            BufferedReader reader = new BufferedReader(new FileReader("test_files\\stresstests\\standard_file.txt"));
            String line;
            StringBuffer buffer = new StringBuffer();
            while ((line = reader.readLine()) != null)
            {
                buffer.append(line);
            }
            reader.close();
            STANDARD_FILE_CONTENT = buffer.toString();
        }
        catch(IOException ioe)
        {
        }
        File root = new File("test_files\\stressdir");
        folders.add(root.getAbsolutePath());
        generate(0, root);
    }

    public void tearDown()
    {
        for(int i = 0; i < files.size(); ++i)
        {
            String name = (String)files.get(i);
            File file = new File(name);
            file.delete();
        }
        for(int i = folders.size() - 1; i >= 0; --i)
        {
            String name = (String)folders.get(i);
            File dir = new File(name);
            dir.delete();
        }
    }

    private void generate(int levelNum, File directory)
    {
        if (levelNum != 0)
        {
            for(int i = 0; i < filesInNode; ++i)
            {
                File file = new File(directory, String.valueOf(i) + ".txt");
                try
                {
                    FileWriter writer = new FileWriter(file);
                    writer.write(STANDARD_FILE_CONTENT);
                    writer.close();
                    files.add(file.getAbsolutePath());
                }
                catch(IOException ioe)
                {
                    ioe.printStackTrace();
                }
            }
        }
        if (levelNum < levels)
        {
            for(int i = 0; i < childrenAtLevel; ++i)
            {
                File subDir = new File(directory, "d" + String.valueOf(i));
                if (subDir.mkdirs())
                {
                    folders.add(subDir.getAbsolutePath());
                    generate(levelNum + 1, subDir);
                }
            }
        }
    }

    /**
     * Processes a hierarchy of files and folders that is deep and wide.
     * The aim being to test the ProcessDirectory feature. And the intermediate
     * data storage structures. A successful test will not throw a StackOverflowException
      * @throws Exception
     */
    public void testProcessLargeHierarchy() throws Exception   {
        // process directory
        long start = new Date().getTime();
        statistics.processDirectory(new File("test_files/stressdir"));
        long duration = new Date().getTime() - start;
        System.out.println("Processing a large number of directories took " + duration + "ms");
    }

    /**
     * Processes a hierarchy of files and folders that is deep and wide.
     * The aim here is to test the report generation mechanism
      * @throws Exception
     */
    public void testReportOnLargeHierarchy() throws Exception   {
        // process directory
        statistics.processDirectory(new File("test_files/stressdir"));
        long start = new Date().getTime();
        statistics.getReporting().generateReport();
        long duration = new Date().getTime() - start;
        System.out.println("Reporting on a large number of directories took " + duration + "ms");
    }
}
