package com.topcoder.file.statistics.stresstests;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;
import com.topcoder.file.statistics.*;
import com.topcoder.file.statistics.reporting.BasicStatsReporting;
import com.topcoder.file.statistics.matcher.*;

import java.util.regex.Pattern;
import java.util.List;
import java.util.ArrayList;
import java.util.Date;
import java.io.*;

public class MatchersTests extends TestCase {
    public static Test suite() {
        return new TestSuite(MatchersTests.class);
    }

    private ExtendedFileStatistics statistics;

    private int numProcessors = 10;

    private String pathToFile = "test_files\\stressdir";

    private int levels = 1;

    private int childrenAtLevel = 1;

    private int filesInNode = 1000;

    private String STANDARD_FILE_CONTENT = "....";

    private List files = new ArrayList();
    private List folders = new ArrayList();

    public void tearDown()
    {
        for(int i = 0; i < files.size(); ++i)
        {
            String name = (String)files.get(i);
            File file = new File(name);
            file.delete();
        }
        for(int i = folders.size() - 1; i >= 0; --i)
        {
            String name = (String)folders.get(i);
            File dir = new File(name);
            dir.delete();
        }
    }

    private void generate(int levelNum, File directory)
    {
        if (levelNum != 0)
        {
            for(int i = 0; i < filesInNode; ++i)
            {
                File file = new File(directory, String.valueOf(i) + ".txt");
                try
                {
                    FileWriter writer = new FileWriter(file);
                    writer.write(STANDARD_FILE_CONTENT);
                    writer.close();
                    files.add(file.getAbsolutePath());
                }
                catch(IOException ioe)
                {
                    ioe.printStackTrace();
                }
            }
        }
        if (levelNum < levels)
        {
            for(int i = 0; i < childrenAtLevel; ++i)
            {
                File subDir = new File(directory, "d" + String.valueOf(i));
                if (subDir.mkdirs())
                {
                    folders.add(subDir.getAbsolutePath());
                    generate(levelNum + 1, subDir);
                }
            }
        }
    }
    public void setUp()
    {
        // create a file statistics instance
        statistics = new ExtendedFileStatistics();

        //assign the report object
        statistics.setReporting(new BasicStatsReporting());

        int k = 0;
        for(int i = 0; i < numProcessors; ++i)
        {
            // create file matchers
            FileMatcher matcher = new AnyFileMatcher();
            statistics.addFileProcessor(new NopProcessor("NOP" + k++, matcher));

            matcher = new ExtensionMatcher("txt");
            statistics.addFileProcessor(new NopProcessor("NOP" + k++, matcher));

            matcher = new RegexMatcher(Pattern.compile("pattern"));
            statistics.addFileProcessor(new NopProcessor("NOP" + k++, matcher));

            matcher = new TextFileMatcher();
            statistics.addFileProcessor(new NopProcessor("NOP" + k++, matcher));

            matcher = new BinaryFileMatcher();
            statistics.addFileProcessor(new NopProcessor("NOP" + k++, matcher));

            matcher = new TypeNameMatcher("Java");
            statistics.addFileProcessor(new NopProcessor("NOP" + k++, matcher));

            matcher = new MimeMatcher("text/plain");
            statistics.addFileProcessor(new NopProcessor("NOP" + k++, matcher));
        }
        try
        {
            BufferedReader reader = new BufferedReader(new FileReader("test_files\\stresstests\\standard_file.txt"));
            String line;
            StringBuffer buffer = new StringBuffer();
            while ((line = reader.readLine()) != null)
            {
                buffer.append(line);
            }
            reader.close();
            STANDARD_FILE_CONTENT = buffer.toString();
        }
        catch(IOException ioe)
        {
        }
        File root = new File("test_files\\stressdir");
        folders.add(root.getAbsolutePath());
        generate(0, root);
    }

    /**
     * Attempts to process one file with a large number of matchers.
     * The aim is to test the algorithm used to process the files in a situation
     * where there are many files and many matchers.
     * @throws Exception
     */
    public void testManyMatchers() throws Exception {
        long start = new Date().getTime();
        statistics.processDirectory(new File(pathToFile), false);
        long duration = new Date().getTime() - start;
        System.out.println("Working with a large number of matchers took " + duration + "ms");
    }
}
